@@ -23,11 +23,19 @@ class InvalidConfig(ConfigError):
     pass
 
 
-class BackupTaskError(RsyncTasksError):
+class TaskError(RsyncTasksError):
     pass
 
 
-class LocalPathNotWritable(BackupTaskError):
+class SourcePathNotExist(TaskError):
+    def __init__(self, path: str):
+        self._path = path
+
+    def __str__(self) -> str:
+        return "Source path '{}' does not exist".format(self._path)
+
+
+class LocalPathNotWritable(TaskError):
     def __init__(self, path: str):
         self._path = path
 
@@ -35,7 +43,7 @@ class LocalPathNotWritable(BackupTaskError):
         return "Directory '{}' is not writable".format(self._path)
 
 
-class IdentityFileUnreadable(BackupTaskError):
+class IdentityFileUnreadable(TaskError):
     def __init__(self, file: str):
         self._file = file
 
@@ -43,7 +51,7 @@ class IdentityFileUnreadable(BackupTaskError):
         return "Identity file '{}' is not readable".format(self._file)
 
 
-class TargetFailed(BackupTaskError):
+class TargetFailed(TaskError):
     def __init__(self, path: str):
         self._path = path
 
@@ -51,5 +59,5 @@ class TargetFailed(BackupTaskError):
         return "Failed sync of '{}'".format(self._path)
 
 
-class TaskFailed(BackupTaskError):
+class TaskFailed(TaskError):
     pass
