@@ -9,7 +9,7 @@ from yamale import YamaleError
 from yaml.scanner import ScannerError
 
 from rsync_tasks import exceptions
-from rsync_tasks.exceptions import BackupTaskError, TaskFailed, LocalPathNotWritable, TargetFailed
+from rsync_tasks.exceptions import TaskFailed, SourcePathNotExist
 
 _LOGGER = logging.getLogger(__package__)
 
@@ -20,12 +20,14 @@ class RsyncTasks:
                  flags: str,
                  base_path_source: str,
                  base_path_destination: str,
+                 stop_on_failed_task: bool = False,
                  **kwargs):
         self._tasks = tasks
 
         self._flags = flags
         self._base_path_source = base_path_source
         self._base_path_destination = base_path_destination
+        self._stop_on_failed_task = stop_on_failed_task
 
         # Checks if the necessary system tools are available
         RsyncTasks._check_tools()
@@ -70,28 +72,23 @@ class RsyncTasks:
 
     def start(self):
         for task in self._tasks:
-            try:
-                source = os.path.join(self._base_path_source, task["s"])
-                destination = os.path.join(self._base_path_destination, task["d"])
+            source = os.path.join(self._base_path_source, task["s"])
+            destination = os.path.join(self._base_path_destination, task["d"])
 
-                # checks if the local path is writable
-                # if not os.access(destination, os.W_OK):
-                #    raise LocalPathNotWritable(str(destination))
+            if not os.path.exists(source):
+                _LOGGER.warning(f"Source path `{source}` does not exists")
+                if self._stop_on_failed_task:
+                    raise SourcePathNotExist(source)
+                continue
 
-                # creates the command for the current target
-                command = self._mk_command(source, destination)
+            # creates the command for the current target
+            command = self._mk_command(source, destination)
+            _LOGGER.debug(f"Run command `{command}`")
 
-                _LOGGER.debug("Run command `{}`".format(command))
-
-                # launches the command
-                if os.system(command) != 0:
-                    _LOGGER.warning("Failed target `{}`".format(command))
-                    raise TargetFailed(task["s"])
-
-            except BackupTaskError as e:
-                _LOGGER.error("Task {} failed\n{}".format(None, e))
-
-                raise TaskFailed(e)
+            if os.system(command) != 0:
+                _LOGGER.warning(f"Failed target `{command}`")
+                if self._stop_on_failed_task:
+                    raise TaskFailed(task["s"])
 
     def _mk_command(self, source: str, destination: str) -> str:
         command = ["rsync"]
